@@ -270,8 +270,7 @@ Plack::Server::Standalone - single process standalone HTTP server
 =head1 SYNOPSIS
 
   % plackup -s Standalone \
-      --host 127.0.0.1 --port 9091 --timeout 120 \
-      --max-keepalive-reqs 20 --keepalive-timeout 5
+      --host 127.0.0.1 --port 9091 --timeout 120
 
 =head1 DESCRIPTION
 
@@ -304,7 +303,7 @@ Number of seconds a request times out. Defaults to 300.
 
 =item max-keepalive-reqs
 
-Max requests per a keep-alive request. Defaults to 100.
+Max requests per a keep-alive request. Defaults to 1, which means Keep-alive is off.
 
 =item keepalive-timeout
 
